/***************************************************************************
 *   Copyright (C) 2005 by David Saxton                                    *
 *   david@bluehaze.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#ifndef NO_GPSIM

#ifndef VARIABLELABEL_H
#define VARIABLELABEL_H

#include <tqguardedptr.h>
#include <tqlabel.h>

class TextView;


/**
Used for displaying the value of a variable when the user hovers his mouse over
a variable while debugging.

@author David Saxton
 */
class VariableLabel : public TQLabel
{
	Q_OBJECT
  
	public:
		VariableLabel( TextView * parent );
		/**
		 * Sets the register that this label is displaying the value of.
		 */
		void setRegister( RegisterInfo * info, const TQString & name );
		/**
		 * Sets the value that this label is displaying. This is an alternative
		 * to setRegister.
		 */
		void setValue( unsigned value );
		
	protected slots:
		/**
		 * Updates what is displayed from m_pRegisterInfo.
		 */
		void updateText();
		
	protected:
		void disconnectRegisterInfo();
		
		TQGuardedPtr<RegisterInfo> m_pRegisterInfo;
		TQString m_registerName;
		int m_value;
};

#endif

#endif // !NO_GPSIM
